==> aria2_1.17.0.orig.tar.bz2: aria2-1.17.0/src/DHTNodeLookupTaskCallback.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2010 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "DHTNodeLookupTaskCallback.h"
#include "DHTNodeLookupTask.h"
#include "DHTAnnouncePeerReplyMessage.h"
#include "DHTGetPeersReplyMessage.h"
#include "DHTPingReplyMessage.h"
#include "DHTFindNodeReplyMessage.h"
#include "Peer.h"

namespace aria2 {

DHTNodeLookupTaskCallback::DHTNodeLookupTaskCallback(DHTNodeLookupTask* task):
  task_(task) {}

void DHTNodeLookupTaskCallback::visit
(const DHTAnnouncePeerReplyMessage* message)
{
  // When wrong message type is received, forced to timeout
  onTimeout(message->getRemoteNode());
}

void DHTNodeLookupTaskCallback::visit(const DHTFindNodeReplyMessage* message)
{
  task_->onReceived(message);
}

void DHTNodeLookupTaskCallback::visit(const DHTGetPeersReplyMessage* message)
{
  // When wrong message type is received, forced to timeout
  onTimeout(message->getRemoteNode());
}

void DHTNodeLookupTaskCallback::visit(const DHTPingReplyMessage* message)
{
  // When wrong message type is received, forced to timeout
  onTimeout(message->getRemoteNode());
}

void DHTNodeLookupTaskCallback::onTimeout
(const SharedHandle<DHTNode>& remoteNode)
{
  task_->onTimeout(remoteNode);
}


} // namespace aria2

==> aria2_1.18.1.orig.tar.bz2: aria2-1.18.1/src/DHTNodeLookupTaskCallback.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2010 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "DHTNodeLookupTaskCallback.h"
#include "DHTNodeLookupTask.h"
#include "DHTAnnouncePeerReplyMessage.h"
#include "DHTGetPeersReplyMessage.h"
#include "DHTPingReplyMessage.h"
#include "DHTFindNodeReplyMessage.h"
#include "Peer.h"

namespace aria2 {

DHTNodeLookupTaskCallback::DHTNodeLookupTaskCallback(DHTNodeLookupTask* task):
  task_(task) {}

void DHTNodeLookupTaskCallback::visit
(const DHTAnnouncePeerReplyMessage* message)
{
  // When wrong message type is received, forced to timeout
  onTimeout(message->getRemoteNode());
}

void DHTNodeLookupTaskCallback::visit(const DHTFindNodeReplyMessage* message)
{
  task_->onReceived(message);
}

void DHTNodeLookupTaskCallback::visit(const DHTGetPeersReplyMessage* message)
{
  // When wrong message type is received, forced to timeout
  onTimeout(message->getRemoteNode());
}

void DHTNodeLookupTaskCallback::visit(const DHTPingReplyMessage* message)
{
  // When wrong message type is received, forced to timeout
  onTimeout(message->getRemoteNode());
}

void DHTNodeLookupTaskCallback::onTimeout
(const std::shared_ptr<DHTNode>& remoteNode)
{
  task_->onTimeout(remoteNode);
}


} // namespace aria2
